<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;

class FCMAnaliseConformidadeFactory
{
    protected $connection;
    protected $alias;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->alias = "c";
    }

    public function getCriterioNaoConformidadeByGestor($params)
    {
        $whereClausules = "";
        $useParams = false;
        if (array_key_exists("NRLOCALCLIENTE", $params)) {
            $whereClausules .= " AND loc.NRLOCALCLIENTE = :NRLOCALCLIENTE";
            $useParams = true;
        }
        if (array_key_exists("NRTIPOLOCALCLI", $params)) {
            $whereClausules .= " AND loc.NRTIPOLOCALCLI = :NRTIPOLOCALCLI";
            $useParams = true;
        }
        if (array_key_exists("NRSETOR", $params)) {
            $whereClausules .= " AND loc.NRSETOR = :NRSETOR";
            $useParams = true;
        }
        if (array_key_exists("DATEBEGIN", $params) || array_key_exists("DATEEND", $params)) {
            if (array_key_exists("DATEBEGIN", $params) && array_key_exists("DATEEND", $params)) {
                $whereClausules .= " AND TRUNC(c.DTHORAAGEND) BETWEEN TO_DATE('" . $params["DATEBEGIN"] . "' , 'DD/MM/YYYY') AND TO_DATE('" . $params["DATEEND"] . "' , 'DD/MM/YYYY')";
                unset($params["DATEBEGIN"]);
                unset($params["DATEEND"]);
            } elseif (array_key_exists("DATEBEGIN", $params)) {
                $whereClausules .= " AND TRUNC(c.DTHORAAGEND) >= TO_DATE('" . $params["DATEBEGIN"] . "' , 'DD/MM/YYYY')";
                unset($params["DATEBEGIN"]);
            } elseif (array_key_exists("DATEEND", $params)) {
                $whereClausules .= " AND TRUNC(c.DTHORAAGEND) <= TO_DATE('" . $params["DATEEND"] . "', 'DD/MM/YYYY')";
                unset($params["DATEEND"]);
            }
            $useParams = true;
        }

        $sql = "SELECT HC.NRFUNCIONARIOPAI, CRIT.NMCRITERIOTARGERCHK AS DSCRITERIOTAREFA, FUNC.NMFUNCIONARIO,
                    FUNC.NRFUNCIONARIO
                    FROM FCM_GERENCIAMENTOCHK GECHK
                    JOIN FCM_TAREFAGERCHK TA
                    ON GECHK.NRGERENCIAMENTOCHK = TA.NRGERENCIAMENTOCHK
                    JOIN FCM_CRITERIOTARGERCHK CRIT
                    ON CRIT.NRTAREFAGERCHK = TA.NRTAREFAGERCHK
                    JOIN FCM_CHECKLISTAGEND CKAGND
                    ON CKAGND.NRCHECKLISTAGEND = GECHK.NRCHECKLISTAGEND
                    JOIN FCM_FUNCIONARIO FUNC
                    ON FUNC.NRFUNCIONARIO = CKAGND.NRFUNCIONARIO
                    JOIN FCM_FUNCIONARIOSHIERARQ HC
                    ON HC.NRFUNCIONARIO = FUNC.NRFUNCIONARIO
                    JOIN FCM_HIERARQUIAFUNC HCFUNC
                    ON HCFUNC.NRHIERARQUIAFUNC = HC.NRHIERARQUIAFUNC
                    JOIN FCM_LOCALCLI LOC
                    ON LOC.NRLOCALCLIENTE = GECHK.NRLOCALCLIENTE
                    WHERE HCFUNC.IDATIVO = 'S'
                    AND CRIT.IDMARCADO = 'S'";
        if ($useParams) {
            $sql .= $whereClausules;
            return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
        } else {
            return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
        }
    }

    public function getCriterioNaoConformidade($param)
    {
        $sql = "SELECT LC.NMLOCALCLIENTE || ' | ' || TLC.NMTIPOLOCALCLI AS NMLOCAL, CTAC.NMCRITERIOTARGERCHK
              FROM FCM_CRITERIOTARGERCHK CTAC
              JOIN FCM_TAREFAGERCHK TAC
                ON CTAC.NRTAREFAGERCHK = TAC.NRTAREFAGERCHK
              JOIN FCM_GERENCIAMENTOCHK GC
                ON TAC.NRGERENCIAMENTOCHK = GC.NRGERENCIAMENTOCHK
              JOIN FCM_LOCALCLI LC
                ON GC.NRLOCALCLIENTE = LC.NRLOCALCLIENTE
              JOIN FCM_TIPOLOCALCLI TLC
                ON LC.NRTIPOLOCALCLI = TLC.NRTIPOLOCALCLI
              JOIN FCM_CRITERIOTAREFACHK CTC  
                ON CTAC.NRCRITERIOTAREFACHK = CTC.NRCRITERIOTAREFACHK
              JOIN FCM_CRITERIOTAREFA CT
                ON CTC.NRCRITERIOTAREFA = CT.NRCRITERIOTAREFA
              WHERE CTAC.IDMARCADO = 'S' " . $param;

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getPrincipalNaoConformidade($param)
    {
        $sql = "SELECT CTGC.NMCRITERIOTARGERCHK, COUNT(CTGC.NRCRITERIOTAREFACHK) AS QTDADE
              FROM FCM_CRITERIOTARGERCHK CTGC
              JOIN FCM_TAREFAGERCHK TGC
                ON CTGC.NRTAREFAGERCHK = TGC.NRTAREFAGERCHK
              WHERE IDMARCADO = 'S'" . $param . "
           GROUP BY CTGC.NRCRITERIOTAREFACHK, CTGC.NMCRITERIOTARGERCHK
           ORDER BY QTDADE DESC";
        
        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }
}
